@@ -1,18 +1,52 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package CPAN::Changes::Markdown;
-BEGIN {
-  $CPAN::Changes::Markdown::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $CPAN::Changes::Markdown::VERSION = '0.2.2';
-}
-
+$CPAN::Changes::Markdown::VERSION = '1.000000';
 # ABSTRACT: Format your Changes file ( or a section of it ) in Markdown
 
-use Moo 1.000008;
-use CPAN::Changes::Markdown::Filter::RuleUtil qw(:all);
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Moo 1.000008 qw( has );
+use CPAN::Changes::Markdown::Filter::RuleUtil qw(
+  rule_VersionsToCode
+  rule_UnderscoredToCode
+  rule_PackageNamesToCode
+);
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -28,6 +62,11 @@ has changes => (
 );
 
 
+
+
+
+
+
 has header_filter => (
   is      => ro =>,
   lazy    => 1,
@@ -38,6 +77,11 @@ has header_filter => (
 );
 
 
+
+
+
+
+
 has line_filter => (
   is      => ro =>,
   lazy    => 1,
@@ -49,6 +93,11 @@ has line_filter => (
 );
 
 
+
+
+
+
+
 sub load {
   my ( $self, $path ) = @_;
   require CPAN::Changes;
@@ -56,6 +105,11 @@ sub load {
 }
 
 
+
+
+
+
+
 sub load_string {
   my ( $self, $string ) = @_;
   require CPAN::Changes;
@@ -63,6 +117,13 @@ sub load_string {
 }
 
 
+
+
+
+
+
+
+
 sub load_utf8 {
   my ( $self, $path ) = @_;
   require Path::Tiny;
@@ -91,6 +152,11 @@ sub _serialize_release {
 }
 
 
+
+
+
+
+
 sub serialize {
   my ( $self, %args ) = @_;
   my %release_args;
@@ -119,7 +185,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -127,7 +193,7 @@ CPAN::Changes::Markdown - Format your Changes file ( or a section of it ) in Mar
 
 =head1 VERSION
 
-version 0.2.2
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -141,9 +207,9 @@ version 0.2.2
 
 Mostly, this is wrapper around CPAN::Changes that just formats the output differently.
 
-Primary use case for me is writing C<Github> release notes.
+Primary use case for me is writing C<GitHub> release notes.
 
-I plan to eventually have hook filters and stuff to highlight various tokens in a C<Github> friendly way.
+I plan to eventually have hook filters and stuff to highlight various tokens in a C<GitHub> friendly way.
 
 =head1 METHODS
 
@@ -173,9 +239,9 @@ Same as C<load> except opens C<file> in C<utf8> mode.
 
 A CPAN::Changes::Markdown::Filter object that can process a header.
 
-=head2 C<header_filter>
+=head2 C<line_filter>
 
-A CPAN::Changes::Markdown::Filter object that can process a header.
+A CPAN::Changes::Markdown::Filter object that can process a line.
 
 =begin MetaPOD::JSON v1.1.0
 
@@ -194,7 +260,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
