@@ -1,24 +1,48 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package CPAN::Changes::Markdown::Filter;
-BEGIN {
-  $CPAN::Changes::Markdown::Filter::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $CPAN::Changes::Markdown::Filter::VERSION = '0.2.2';
-}
-
+$CPAN::Changes::Markdown::Filter::VERSION = '1.000000';
 # ABSTRACT: a simple plug-in based, staged text filter for Markdown translation
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
-use Moo 1.000008;
+
+
+
+
+
+
+
+
+
+
+use Moo 1.000008 qw( with has );
 use CPAN::Changes::Markdown::Filter::NodeUtil qw(mk_node_plaintext);
 
 
+
+
+
+
+
+
+
+
+
+
+
+
 with 'CPAN::Changes::Markdown::Role::Filter';
 
 
+
+
+
+
+
 has rules => (
   is      => ro =>,
   lazy    => 1,
@@ -28,6 +52,11 @@ has rules => (
 );
 
 
+
+
+
+
+
 sub process {
   my ( $self, $input ) = @_;
   my (@input) = ( mk_node_plaintext($input) );
@@ -43,7 +72,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -51,7 +80,7 @@ CPAN::Changes::Markdown::Filter - a simple plug-in based, staged text filter for
 
 =head1 VERSION
 
-version 0.2.2
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -91,7 +120,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
