@@ -1,23 +1,43 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package CPAN::Changes::Markdown::Filter::Passthrough;
-BEGIN {
-  $CPAN::Changes::Markdown::Filter::Passthrough::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $CPAN::Changes::Markdown::Filter::Passthrough::VERSION = '0.2.2';
-}
-
+$CPAN::Changes::Markdown::Filter::Passthrough::VERSION = '1.000000';
 # ABSTRACT: A Filter drop-in that doesn't process anything.
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
-use Moo;
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+use Moo qw( with );
 
 with 'CPAN::Changes::Markdown::Role::Filter';
 
 
+
+
+
 ## no critic (RequireArgUnpacking)
 
 sub process {
@@ -30,7 +50,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -38,7 +58,7 @@ CPAN::Changes::Markdown::Filter::Passthrough - A Filter drop-in that doesn't pro
 
 =head1 VERSION
 
-version 0.2.2
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -68,7 +88,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
