@@ -1,29 +1,40 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package CPAN::Changes::Markdown::Role::Filter::Rule;
-BEGIN {
-  $CPAN::Changes::Markdown::Role::Filter::Rule::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $CPAN::Changes::Markdown::Role::Filter::Rule::VERSION = '0.2.2';
-}
-
+$CPAN::Changes::Markdown::Role::Filter::Rule::VERSION = '1.000000';
 # ABSTRACT: A step filter
 
-use Role::Tiny;
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Role::Tiny qw( requires );
+
+
+
 
 
 requires 'filter';
 
 
+
+
+
+
+
+
+
+
+
+
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -31,7 +42,7 @@ CPAN::Changes::Markdown::Role::Filter::Rule - A step filter
 
 =head1 VERSION
 
-version 0.2.2
+version 1.000000
 
 =head1 ROLE REQUIRES
 
@@ -53,7 +64,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
